@@ -1,3 +1,6 @@
+"""
+This module contains the ScreenManager. The backbone of the FangEngine
+"""
 import pygame
 import screeninfo
 import os
@@ -16,11 +19,27 @@ pygame.mixer.init()
 
 
 class ScreenManager:
+    """
+    This module contains the ScreenManager. The backbone of the FangEngine
+    The ScreenManager is responsible for handling all screens, scaling them, switching them and dispatching all events
+    """
     def __init__(
             self, screen_w: int = 800, screen_h: int = 450, fullscreen: bool = False, monitor: int = 0,
             show_cursor: bool = True, caption: str = "FangEngine Application", framerate_cap: int = 60,
             icon_path: str = None
     ):
+        """
+        Note that this method allows you to set fullscreen, monitor and framerate_cap.
+        It is best practice to allow the user choose this at runtime. This can be done by calling show_graphics_options
+        :param screen_w: The width of the working space. This will be scaled based on user window interaction
+        :param screen_h: The height of the working space. This will be scaled based on user window interaction
+        :param fullscreen:
+        :param monitor:
+        :param show_cursor:
+        :param caption: The title for the window
+        :param framerate_cap:
+        :param icon_path: the path to the image for the window icon
+        """
         self.screen_w = screen_w
         self.screen_h = screen_h
         self.fullscreen = fullscreen
@@ -45,6 +64,12 @@ class ScreenManager:
         image_asset_store.ImageAssetStore()
 
     def show_graphics_options(self, caption: str = None, icon_path: str = None) -> 'ScreenManager':
+        """
+        This method allows the users to select their graphics options
+        :param caption: default is to take the value set in the constructor
+        :param icon_path: default is to take the value set in the constructor
+        :return: this object so this statement can be chained
+        """
         if caption is None:
             caption = self.caption
 
@@ -60,6 +85,14 @@ class ScreenManager:
         return self
 
     def add_screen(self, name: str, screen_cls: 'screen.BaseScreen.__class__', *args, **kwargs) -> 'ScreenManager':
+        """
+        Adds a new screen to the manager
+        :param name: the reference name of the screen
+        :param screen_cls: a reference to the class of the screen. It MUST inherit from BaseScreen
+        :param args:
+        :param kwargs:
+        :return: this object so this statement can be chained
+        """
         new_screen = screen_cls(name, self, *args, **kwargs)        # type: screen.BaseScreen
         self.screens[name] = new_screen
 
@@ -68,11 +101,21 @@ class ScreenManager:
         return self
 
     def add_instantiated_screen(self, screen_obj: 'screen.BaseScreen') -> 'ScreenManager':
+        """
+        Adds an already instantiated screen
+        WARNING: DO NOT INSTANTIATE A SCREEN OBJECT ON YOUR OWN. Let the engine handle it
+        :param screen_obj:
+        :return: this object so this statement can be chained
+        """
         self.screens[screen_obj.name] = screen_obj
 
         return self
 
     def change_screen(self, name: str) -> 'ScreenManager':
+        """
+        Changes the currently selected screen
+        :return: this object so this statement can be chained
+        """
         if self.selected_screen is not None:
             previous_screen = self.selected_screen.name
             self.selected_screen.on_screen_leave(name)
@@ -85,6 +128,11 @@ class ScreenManager:
         return self
 
     def show_screen(self, initial_screen: str = None) -> 'ScreenManager':
+        """
+        Launches the GUI window. It is best practice to call "start" method instead which will handle this
+        :param initial_screen: the screen to start on
+        :return: this object so this statement can be chained
+        """
         if initial_screen is not None:
             self.change_screen(initial_screen)
 
@@ -125,6 +173,9 @@ class ScreenManager:
         self.buff_draw_y = self.surface.get_height() / 2 - (self.screen_h * self.scale_factor) / 2
 
     def draw_buffer(self):
+        """
+        Scales and draws the buffer (which is passed to all objects for them to do their drawing with) to the window
+        """
         if self.scale_factor == 1:
             buff = self.buffer
         else:
@@ -138,12 +189,24 @@ class ScreenManager:
 
     @staticmethod
     def clear_event_queue():
+        """
+        Clears the event queue
+        :return:
+        """
         pygame.event.clear()
 
     def scale_coords(self, pos: typing.Tuple[float, float]) -> typing.Tuple[float, float]:
+        """
+        Scales coordinates relative to the scaling of the window
+        """
         return (pos[0] - self.buff_draw_x) / self.scale_factor, (pos[1] - self.buff_draw_y) / self.scale_factor
 
     def start(self, initial_screen: str = None) -> status_codes.StatusCodes:
+        """
+        Starts the application
+        :param initial_screen: the screen to start the game on
+        :return: the status code as to why the game terminated. This will be a value from the StatusCodes enum
+        """
         try:
             if not self.showing_screen:
                 self.show_screen(initial_screen=initial_screen)
