@@ -1,3 +1,6 @@
+"""
+This module contains the SystemConsoleScreen
+"""
 import pygame
 import os
 import subprocess
@@ -8,11 +11,24 @@ pygame.font.init()
 
 
 class SystemConsoleScreen(base_console_screen.BaseConsoleScreen):
+    """
+    The SystemConsoleScreen simulates a terminal (ex. cmd on Windows and Bash on Linux)
+    """
     def __init__(self, name: str, manager, font: pygame.font.Font):
+        """
+        :param name:
+        :param manager:
+        :param font: The pygame font to render all text as
+        """
         super().__init__(name, manager, font)
         self.set_prompt(os.getcwd() + "> ")
 
     def on_input(self, command: str):
+        """
+        This event is triggered whenever the user inputs a command
+        :param command:
+        :return:
+        """
         if command == "":
             return
 
