@@ -9,10 +9,13 @@ pygame.mixer.init()
 
 class SoundAssetStore(asset_store.AssetStore):
     """
-    Supported formats:
-    OGG, MP3, XM, MOD
+    By default, loads all assets saved in assets/sounds
+    Images are saved with dot notation in all lowercase without the file extension
 
-    NOTE: OGG is preferred
+    For example, the image assets/sounds/player/step.ogg would be referenced by player.step
+
+    Supported formats (.ogg is preferred):
+    OGG, MP3, XM, MOD
     """
     asset_path = os.path.join("assets", "sounds")
 
